==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/MATERIALSADJUSTMENTS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for MATERIALSADJUSTMENTS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="MATERIALSADJUSTMENTS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MATERIALSADJUSTMENT0" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MATERIALSADJUSTMENT1" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MATERIALSADJUSTMENT2" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MATERIALSADJUSTMENT3" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MATERIALSADJUSTMENT4" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MATERIALSADJUSTMENT5" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MATERIALSADJUSTMENT6" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MATERIALSADJUSTMENT7" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MATERIALSADJUSTMENT8" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MATERIALSADJUSTMENT9" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "MATERIALSADJUSTMENTS_Type", propOrder = {
    "materialsadjustment0",
    "materialsadjustment1",
    "materialsadjustment2",
    "materialsadjustment3",
    "materialsadjustment4",
    "materialsadjustment5",
    "materialsadjustment6",
    "materialsadjustment7",
    "materialsadjustment8",
    "materialsadjustment9"
})
public class MATERIALSADJUSTMENTS_Type {

    @XmlElement(name = "MATERIALSADJUSTMENT0")
    protected USERDEFINEDCODEID_Type materialsadjustment0;
    @XmlElement(name = "MATERIALSADJUSTMENT1")
    protected USERDEFINEDCODEID_Type materialsadjustment1;
    @XmlElement(name = "MATERIALSADJUSTMENT2")
    protected USERDEFINEDCODEID_Type materialsadjustment2;
    @XmlElement(name = "MATERIALSADJUSTMENT3")
    protected USERDEFINEDCODEID_Type materialsadjustment3;
    @XmlElement(name = "MATERIALSADJUSTMENT4")
    protected USERDEFINEDCODEID_Type materialsadjustment4;
    @XmlElement(name = "MATERIALSADJUSTMENT5")
    protected USERDEFINEDCODEID_Type materialsadjustment5;
    @XmlElement(name = "MATERIALSADJUSTMENT6")
    protected USERDEFINEDCODEID_Type materialsadjustment6;
    @XmlElement(name = "MATERIALSADJUSTMENT7")
    protected USERDEFINEDCODEID_Type materialsadjustment7;
    @XmlElement(name = "MATERIALSADJUSTMENT8")
    protected USERDEFINEDCODEID_Type materialsadjustment8;
    @XmlElement(name = "MATERIALSADJUSTMENT9")
    protected USERDEFINEDCODEID_Type materialsadjustment9;

    /**
     * Gets the value of the materialsadjustment0 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getMATERIALSADJUSTMENT0() {
        return materialsadjustment0;
    }

    /**
     * Sets the value of the materialsadjustment0 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setMATERIALSADJUSTMENT0(USERDEFINEDCODEID_Type value) {
        this.materialsadjustment0 = value;
    }

    /**
     * Gets the value of the materialsadjustment1 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getMATERIALSADJUSTMENT1() {
        return materialsadjustment1;
    }

    /**
     * Sets the value of the materialsadjustment1 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setMATERIALSADJUSTMENT1(USERDEFINEDCODEID_Type value) {
        this.materialsadjustment1 = value;
    }

    /**
     * Gets the value of the materialsadjustment2 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getMATERIALSADJUSTMENT2() {
        return materialsadjustment2;
    }

    /**
     * Sets the value of the materialsadjustment2 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setMATERIALSADJUSTMENT2(USERDEFINEDCODEID_Type value) {
        this.materialsadjustment2 = value;
    }

    /**
     * Gets the value of the materialsadjustment3 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getMATERIALSADJUSTMENT3() {
        return materialsadjustment3;
    }

    /**
     * Sets the value of the materialsadjustment3 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setMATERIALSADJUSTMENT3(USERDEFINEDCODEID_Type value) {
        this.materialsadjustment3 = value;
    }

    /**
     * Gets the value of the materialsadjustment4 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getMATERIALSADJUSTMENT4() {
        return materialsadjustment4;
    }

    /**
     * Sets the value of the materialsadjustment4 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setMATERIALSADJUSTMENT4(USERDEFINEDCODEID_Type value) {
        this.materialsadjustment4 = value;
    }

    /**
     * Gets the value of the materialsadjustment5 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getMATERIALSADJUSTMENT5() {
        return materialsadjustment5;
    }

    /**
     * Sets the value of the materialsadjustment5 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setMATERIALSADJUSTMENT5(USERDEFINEDCODEID_Type value) {
        this.materialsadjustment5 = value;
    }

    /**
     * Gets the value of the materialsadjustment6 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getMATERIALSADJUSTMENT6() {
        return materialsadjustment6;
    }

    /**
     * Sets the value of the materialsadjustment6 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setMATERIALSADJUSTMENT6(USERDEFINEDCODEID_Type value) {
        this.materialsadjustment6 = value;
    }

    /**
     * Gets the value of the materialsadjustment7 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getMATERIALSADJUSTMENT7() {
        return materialsadjustment7;
    }

    /**
     * Sets the value of the materialsadjustment7 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setMATERIALSADJUSTMENT7(USERDEFINEDCODEID_Type value) {
        this.materialsadjustment7 = value;
    }

    /**
     * Gets the value of the materialsadjustment8 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getMATERIALSADJUSTMENT8() {
        return materialsadjustment8;
    }

    /**
     * Sets the value of the materialsadjustment8 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setMATERIALSADJUSTMENT8(USERDEFINEDCODEID_Type value) {
        this.materialsadjustment8 = value;
    }

    /**
     * Gets the value of the materialsadjustment9 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getMATERIALSADJUSTMENT9() {
        return materialsadjustment9;
    }

    /**
     * Sets the value of the materialsadjustment9 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setMATERIALSADJUSTMENT9(USERDEFINEDCODEID_Type value) {
        this.materialsadjustment9 = value;
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_fields/MATERIALSADJUSTMENTS_Type.java <==

package net.datastream.schemas.mp_fields;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for MATERIALSADJUSTMENTS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="MATERIALSADJUSTMENTS_Type">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}MATERIALSADJUSTMENT0" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}MATERIALSADJUSTMENT1" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}MATERIALSADJUSTMENT2" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}MATERIALSADJUSTMENT3" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}MATERIALSADJUSTMENT4" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}MATERIALSADJUSTMENT5" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}MATERIALSADJUSTMENT6" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}MATERIALSADJUSTMENT7" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}MATERIALSADJUSTMENT8" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}MATERIALSADJUSTMENT9" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "MATERIALSADJUSTMENTS_Type", propOrder = {
    "materialsadjustment0",
    "materialsadjustment1",
    "materialsadjustment2",
    "materialsadjustment3",
    "materialsadjustment4",
    "materialsadjustment5",
    "materialsadjustment6",
    "materialsadjustment7",
    "materialsadjustment8",
    "materialsadjustment9"
})
public class MATERIALSADJUSTMENTS_Type {

    @XmlElement(name = "MATERIALSADJUSTMENT0")
    protected USERDEFINEDCODEID_Type materialsadjustment0;
    @XmlElement(name = "MATERIALSADJUSTMENT1")
    protected USERDEFINEDCODEID_Type materialsadjustment1;
    @XmlElement(name = "MATERIALSADJUSTMENT2")
    protected USERDEFINEDCODEID_Type materialsadjustment2;
    @XmlElement(name = "MATERIALSADJUSTMENT3")
    protected USERDEFINEDCODEID_Type materialsadjustment3;
    @XmlElement(name = "MATERIALSADJUSTMENT4")
    protected USERDEFINEDCODEID_Type materialsadjustment4;
    @XmlElement(name = "MATERIALSADJUSTMENT5")
    protected USERDEFINEDCODEID_Type materialsadjustment5;
    @XmlElement(name = "MATERIALSADJUSTMENT6")
    protected USERDEFINEDCODEID_Type materialsadjustment6;
    @XmlElement(name = "MATERIALSADJUSTMENT7")
    protected USERDEFINEDCODEID_Type materialsadjustment7;
    @XmlElement(name = "MATERIALSADJUSTMENT8")
    protected USERDEFINEDCODEID_Type materialsadjustment8;
    @XmlElement(name = "MATERIALSADJUSTMENT9")
    protected USERDEFINEDCODEID_Type materialsadjustment9;

    /**
     * Gets the value of the materialsadjustment0 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getMATERIALSADJUSTMENT0() {
        return materialsadjustment0;
    }

    /**
     * Sets the value of the materialsadjustment0 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setMATERIALSADJUSTMENT0(USERDEFINEDCODEID_Type value) {
        this.materialsadjustment0 = value;
    }

    /**
     * Gets the value of the materialsadjustment1 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getMATERIALSADJUSTMENT1() {
        return materialsadjustment1;
    }

    /**
     * Sets the value of the materialsadjustment1 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setMATERIALSADJUSTMENT1(USERDEFINEDCODEID_Type value) {
        this.materialsadjustment1 = value;
    }

    /**
     * Gets the value of the materialsadjustment2 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getMATERIALSADJUSTMENT2() {
        return materialsadjustment2;
    }

    /**
     * Sets the value of the materialsadjustment2 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setMATERIALSADJUSTMENT2(USERDEFINEDCODEID_Type value) {
        this.materialsadjustment2 = value;
    }

    /**
     * Gets the value of the materialsadjustment3 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getMATERIALSADJUSTMENT3() {
        return materialsadjustment3;
    }

    /**
     * Sets the value of the materialsadjustment3 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setMATERIALSADJUSTMENT3(USERDEFINEDCODEID_Type value) {
        this.materialsadjustment3 = value;
    }

    /**
     * Gets the value of the materialsadjustment4 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getMATERIALSADJUSTMENT4() {
        return materialsadjustment4;
    }

    /**
     * Sets the value of the materialsadjustment4 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setMATERIALSADJUSTMENT4(USERDEFINEDCODEID_Type value) {
        this.materialsadjustment4 = value;
    }

    /**
     * Gets the value of the materialsadjustment5 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getMATERIALSADJUSTMENT5() {
        return materialsadjustment5;
    }

    /**
     * Sets the value of the materialsadjustment5 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setMATERIALSADJUSTMENT5(USERDEFINEDCODEID_Type value) {
        this.materialsadjustment5 = value;
    }

    /**
     * Gets the value of the materialsadjustment6 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getMATERIALSADJUSTMENT6() {
        return materialsadjustment6;
    }

    /**
     * Sets the value of the materialsadjustment6 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setMATERIALSADJUSTMENT6(USERDEFINEDCODEID_Type value) {
        this.materialsadjustment6 = value;
    }

    /**
     * Gets the value of the materialsadjustment7 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getMATERIALSADJUSTMENT7() {
        return materialsadjustment7;
    }

    /**
     * Sets the value of the materialsadjustment7 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setMATERIALSADJUSTMENT7(USERDEFINEDCODEID_Type value) {
        this.materialsadjustment7 = value;
    }

    /**
     * Gets the value of the materialsadjustment8 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getMATERIALSADJUSTMENT8() {
        return materialsadjustment8;
    }

    /**
     * Sets the value of the materialsadjustment8 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setMATERIALSADJUSTMENT8(USERDEFINEDCODEID_Type value) {
        this.materialsadjustment8 = value;
    }

    /**
     * Gets the value of the materialsadjustment9 property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getMATERIALSADJUSTMENT9() {
        return materialsadjustment9;
    }

    /**
     * Sets the value of the materialsadjustment9 property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setMATERIALSADJUSTMENT9(USERDEFINEDCODEID_Type value) {
        this.materialsadjustment9 = value;
    }

}
